<?php
$path = trim($_SERVER['PATH_INFO']);
$year = 2007;

# /へのアクセスをプログラムにリダイレクト
if (empty($path)) {
	header('Location: index.php/');
	exit;
}

# ZIP読み込み関数
function pon_open_zip($year, $p, $path) {
	if (strpos($path, '//') !== FALSE || strpos($path, '..') !== FALSE) {
		exit;
	}
	if (strpos($p, '//') !== FALSE || strpos($p, '..') !== FALSE) {
		exit;
	}
	
	$base = dirname(__FILE__);
	$zipfile = "$base/$year/$p.zip";
	if (file_exists('Zip.php')) {
		# Zip.phpを使う場合
		require_once 'Zip.php';
		$zip = new Archive_Zip($zipfile);
		$data = $zip->extract(array('extract_as_string' => true, 'by_name' => array($path)));
		$data = $data[0]['content'];
		$fh = fopen('data://text/plain,'.$data,'r');
	}
	else {
		# zip:スキームを使う場合
		$file = "zip://$zipfile#$path";
		$fh = @fopen($file,'r');
		if ($fh === FALSE) {
			exit;
		}
	}
	return $fh;
}

# CSVを1行取得
function pon_get_csv($fh) {
	$line = fgets($fh);
	if ($line === FALSE) {
		return FALSE;
	}
	return explode(',', $line);
}
?><!DOCTYPE html>
<html>
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
    <meta charset="UTF-8"/>
<?php

if ($path == '/' || $path == '/index.html') {
	# トップページ
	$fh = fopen($year.'/0', 'r');
	$i = 0;
	?>
    <title>住所でポン！</title>
  </head>
  <body>
  <h1>住所でポン！</h1>
	<ol>
	<?php
	while (($data = pon_get_csv($fh)) !== FALSE) {
		?>
		<li><a href="<?php echo ++$i; ?>/index.html"><?php echo htmlspecialchars($data[0]); ?></a></li>
		<?php
	}
	?>
	</ol>
	<?php
	fclose($fh);
}
else {
	# 詳細
	if (preg_match('/^\\/([0-9]+)\\/index.html/', $path, $matches) == 1) {
		# 都道府県
		$fh = fopen($year.'/'.$matches[1].'/0', 'r');
	}
	else if (preg_match('/^\\/([0-9]+)\\/([0-9]+)\\/index.html/', $path, $matches) == 1) {
		# 市区町村
		$z = (int)$matches[2];
		$z = (int)(($z - 1) / 10) + 1;
		$fh = pon_open_zip($year, $matches[1].'/'.$z, $matches[2].'/0');
	}
	else if (preg_match('/^\\/([0-9]+)\\/([0-9]+)\\/([0-9]+).html/', $path, $matches) == 1) {
		# 小区域
		$z = (int)$matches[2];
		$z = (int)(($z - 1) / 10) + 1;
		$fh = pon_open_zip($year, $matches[1].'/'.$z, $matches[2].'/'.$matches[3]);
	}

	$data = pon_get_csv($fh);
	switch (count($data)) {
		case 1:
		# 都道府県
		?>
    <title>住所でポン！ <?php echo $data[0]; ?></title>
  </head>
  <body>
		<h2>
		<a href="../index.html">住所でポン！</a>
		<?php echo $data[0]; ?>
		</h2>
		<?php
		$i = 0;
		?>
		<ol>
		<?php
		while (($data = pon_get_csv($fh)) !== FALSE) {
			?>
			<li><a href="<?php echo ++$i; ?>/index.html"><?php echo htmlspecialchars($data[0]); ?></a></li>
			<?php
		}
		?>
		</ol>
		<?php
		break;
		
		case 2:
		# 市区町村
		?>
    <title>住所でポン！ <?php echo $data[0]; ?><?php echo $data[1]; ?></title>
  </head>
  <body>
 		<h2>
 		<a href="../../index.html">住所でポン！</a>
		<a href="../index.html"><?php echo $data[0]; ?></a>
		<?php echo $data[1]; ?>
		</h2>
		<?php
		$i = 0;
		?>
		<ol>
		<?php
		while (($data = pon_get_csv($fh)) !== FALSE) {
			?>
			<li><a href="<?php echo ++$i; ?>.html"><?php echo htmlspecialchars($data[0]); ?></a></li>
			<?php
		}
		?>
		</ol>
		<?php
		break;
		
		case 3:
		# 小区域
		?>
    <title>住所でポン！ <?php echo $data[0]; ?><?php echo $data[1]; ?><?php echo $data[2]; ?></title>
  </head>
  <body>
		<h2>
		<a href="../../index.html">住所でポン！</a>
		<a href="../index.html"><?php echo $data[0]; ?></a>
		<a href="index.html"><?php echo $data[1]; ?></a>
		<?php echo $data[2]; ?>
		</h2>
		<?php
		$pref = $data[0];
		$city = $data[1];
		$street1 = $data[2];
		$i = 0;
		?>
		<table class="data">
		<thead>
		<tr>
		<th>電話番号</th>
		<th>名前</th>
		<th>住所</th>
		</tr>
		</thead>
		<tbody>
		<?php
		while (($data = pon_get_csv($fh)) !== FALSE) {
			$address = htmlspecialchars($pref.$city.$street1.$data[2]);
			?>
			<tr>
			<td><a href="http://www.jpnumber.com/searchnumber.do?number=<?php echo $data[0]; ?>" target="_blank"><?php echo $data[0]; ?></a></td>
			<td><a href="http://spysee.jp/search?q=<?php echo htmlspecialchars($data[1]); ?>" target="_blank"><?php echo htmlspecialchars($data[1]); ?></a></td>
			<td><a href="https://www.google.co.jp/maps/preview?safe=off&q=<?php echo $address; ?>" target="_blank"><?php echo $address; ?></a></td>
			<td class="strike"></td>
			</tr>
			<?php
		}
		?>
		</tbody>
		</table>
        <?php
		break;
	}

	fclose($fh);
}
?>
  <hr>
  <p>
  </body>
</html>
